@@ -14,10 +14,11 @@ config = Config()
 
 
 class Display:
-    def __init__(self,
-                 theme_color: str = config.theme_color,
-                 pom_name: str = config.pom_name,
-                 ):
+    def __init__(
+        self,
+        theme_color: str = config.theme_color,
+        pom_name: str = config.pom_name,
+    ):
         self.theme = self.color_map(theme_color)
         self.pom_name = pom_name
 
@@ -28,8 +29,7 @@ class Display:
             return f"{self.theme}{string}{Style.RESET_ALL}"
 
     def print_poms(self, string: str):
-        col_str = self.col(string, 'black')
-        return f"{Back.YELLOW}{col_str}{Style.RESET_ALL}"
+        return f"{self.col(Back.LIGHTMAGENTA_EX + string + ' ' + self.add_plurality(self.pom_name), 'white')}"
 
     def print_timer(self, mode: str, timer_val: int, tasks: List = None):
         if mode == "work":
@@ -69,10 +69,17 @@ class Display:
         )
 
     def print_bar_header(self):
-        print(f"{self.col('Weekly Minutes', 'yellow')}")
+        print(
+            f"{self.col('Daily work/rest minutes, for the past fortnight', 'yellow')}"
+        )
+
+    def print_poms_bar_header(self):
+        print(
+            f"\n{self.col(f'Weekly {self.add_plurality(self.pom_name)}, for the past fortnight', 'yellow')}"
+        )
 
     def print_heat_header(self):
-        print(f"{self.col('Work Heatmap', 'yellow')}")
+        print(f"{self.col(f'{self.add_plurality(self.pom_name)} heatmap', 'yellow')}")
 
     def cursor(self):
         return self.col(">> ", "yellow")
@@ -122,10 +129,10 @@ class Display:
         print(f"{self.col('Pick a task to DELETE')}")
 
     def fix_indent(self):
-        num = len('pomodoro') - len(self.pom_name)
-        fix_str = ''
+        num = len("pomodoro") - len(self.pom_name)
+        fix_str = ""
         for no in range(0, num):
-            fix_str += ' '
+            fix_str += " "
         return fix_str
 
     def print_splash(self, durations: Durations, mode: str):
@@ -167,34 +174,57 @@ class Display:
         if tasks:
             print(f'{self.col(f"Completed tasks")}\n')
             print(
-                "\n".join("".join(map(str,
-                                      f"{self.trim_string(self.col(t[2],'green'),45)}"))
-                          for t in tasks if t[4] == '1'))
+                "\n".join(
+                    "".join(map(str, f"{self.trim_string(self.col(t[2],'green'),45)}"))
+                    for t in tasks
+                    if t[4] == "1"
+                )
+            )
             print("\n")
-            print(f'{self.col(f"Incomplete tasks")}\n')
-            print("\n".join("".join(map(str,
-                                        f"{self.add_plurality(self.pom_name)}: "
-                                        f"{self.print_poms(t[3])}"
-                                        f"\n{tr.fill(t[2], 45)}\n"))
-                            for t in tasks if t[4] == '0'))
+            print(f'{self.col(f"Incomplete tasks")}')
+            print(
+                "\n".join(
+                    "".join(
+                        map(str, f"\n{self.print_poms(t[3])}: " f"{tr.fill(t[2], 45)}")
+                    )
+                    for t in tasks
+                    if t[4] == "0"
+                )
+            )
             print("\n")
 
     def print_tasks_with_id(self, tasks: List = None):
         if tasks:
             print(f'{self.col(f"Completed tasks")}\n')
             print(
-                "\n".join("".join(map(str,
-                                      f"{self.col(t[0], 'yellow')}   "
-                                      f"{self.trim_string(self.col(t[2],'green'),45)}"))
-                          for t in tasks if t[4] == '1'))
+                "\n".join(
+                    "".join(
+                        map(
+                            str,
+                            f"{self.col(t[0], 'yellow')}  "
+                            f"{self.trim_string(self.col(t[2],'green'),45)}",
+                        )
+                    )
+                    for t in tasks
+                    if t[4] == "1"
+                )
+            )
             print("\n")
             print(f'{self.col(f"Incomplete tasks")}\n')
-            print("\n".join("".join(map(str,
-                                        f"{self.col(t[0], 'yellow')}   "
-                                        f"{self.add_plurality(self.pom_name)}: "
-                                        f"{self.print_poms(t[3])}"
-                                        f"\n{tr.fill(t[2], 45)}\n"))
-                            for t in tasks if t[4] == '0'))
+            print(
+                "\n".join(
+                    "".join(
+                        map(
+                            str,
+                            f"{self.col(t[0], 'yellow')}  "
+                            f"{self.print_poms(t[3])}: "
+                            f"{tr.fill(t[2], 45)}\n",
+                        )
+                    )
+                    for t in tasks
+                    if t[4] == "0"
+                )
+            )
             print("\n")
 
     def print_header_small(self):
@@ -213,6 +243,10 @@ class Display:
             "magenta": Fore.MAGENTA,
             "white": Fore.WHITE,
             "black": Fore.BLACK,
+            "cyan": Fore.CYAN,
+            "lcyan": Fore.LIGHTCYAN_EX,
+            "grey": Fore.LIGHTBLACK_EX,
+            "lmagenta": Fore.LIGHTMAGENTA_EX,
         }
         return colors[color]
 
@@ -229,11 +263,11 @@ class Display:
 
     @staticmethod
     def add_plurality(string: str):
-        if string[-1] == 's':
+        if string[-1] == "s":
             return string
         else:
-            return string + 's'
+            return string + "s"
 
     @staticmethod
     def trim_string(string: str, max_len: int) -> str:
-        return (string[:max_len] + '..') if len(string) > max_len else string
+        return (string[:max_len] + "..") if len(string) > max_len else string
