@@ -7,6 +7,7 @@ from sylo.definitions import (
     TODAY_STR,
     TASK_FILE_LOCATION,
     CONFIG_FILE_LOCATION,
+    POMS_DATA_FILE_LOCATION,
 )
 from sylo.utils import check_for_file, mins_to_secs
 import tomli
@@ -103,50 +104,67 @@ class ConfigFile:
 
 
 class DataPersistence:
-    def __init__(self, data_file: str = DATA_FILE_LOCATION):
+    def __init__(
+        self,
+        data_file: str = DATA_FILE_LOCATION,
+        poms_data_file: str = POMS_DATA_FILE_LOCATION,
+    ):
         self.data_file = data_file
-        self.file_cols = ["date", "time_worked", "time_rested", "poms"]
+        self.poms_data_file = poms_data_file
+        self.file_cols = ["date", "time_worked", "time_rested"]
+        self.pom_file_cols = ["date", "poms"]
 
     def data_refresh(self, durations: Durations):
         new_df = self.fetch_and_update_values(durations, TODAY_STR)
         new_df.to_csv(DATA_FILE_LOCATION, sep=",", mode="w", header=False)
+        new_df_poms = self.fetch_and_update_values_poms(durations, TODAY_STR)
+        new_df_poms.to_csv(POMS_DATA_FILE_LOCATION, sep=",", mode="w", header=False)
 
     def data_load_on_boot(self, durations: Durations):
-        df = self._read_file()
+        df = self._read_file_to_df(self.data_file, self.file_cols)
+        poms_df = self._read_file_to_df(self.poms_data_file, self.pom_file_cols)
         try:
             filtered_dates = df.loc[TODAY_STR]
             logger.info("data_load_on_boot Found data for today")
             work_time_today = float(filtered_dates["time_worked"])
             rest_time_today = float(filtered_dates["time_rested"])
-            poms_today = float(filtered_dates["poms"])
             logger.info(f"Work time loaded on boot: {work_time_today}")
             logger.info(f"Rest time loaded on boot: {rest_time_today}")
-            logger.info(f"Rest time loaded on boot: {poms_today}")
             durations.total_work_mins = work_time_today
             durations.total_rest_mins = rest_time_today
-            durations.poms = poms_today
         except Exception:
             logger.info("data_load_on_boot NO DATA for today")
             filtered_dates = None
         if filtered_dates is None:
             durations.total_rest_mins = 0
             durations.total_work_mins = 0
+
+        try:
+            filtered_dates = poms_df.loc[TODAY_STR]
+            logger.info("data_load_on_boot Found data for today")
+            poms_today = float(filtered_dates["poms"])
+            logger.info(f"Rest time loaded on boot: {poms_today}")
+            durations.poms = poms_today
+        except Exception:
+            logger.info("data_load_on_boot NO DATA for today")
+            filtered_dates = None
+        if filtered_dates is None:
             durations.poms = 0
 
-    def _read_file(self):
-        df = pd.read_csv(self.data_file, header=None, sep=",")
-        df.columns = self.file_cols
+    @staticmethod
+    def _read_file_to_df(data_file: str, cols: List):
+        df = pd.read_csv(data_file, header=None, sep=",")
+        df.columns = cols
         df.set_index("date", inplace=True, drop=True)
         return df
 
     def fetch_and_update_values(self, durations: Durations, date: str = TODAY_STR):
-        df = self._read_file()
+        df = self._read_file_to_df(self.data_file, self.file_cols)
         new_df = pd.DataFrame(
             {
                 "date": [date],
                 "time_worked": [durations.total_work_mins],
                 "time_rested": [durations.total_rest_mins],
-                "poms": [durations.poms]
             },
             columns=self.file_cols,
             dtype="float",
@@ -155,6 +173,17 @@ class DataPersistence:
         out = new_df.combine_first(df)
         return out
 
+    def fetch_and_update_values_poms(self, durations: Durations, date: str = TODAY_STR):
+        df = self._read_file_to_df(self.poms_data_file, self.pom_file_cols)
+        new_df = pd.DataFrame(
+            {"date": [date], "poms": [durations.poms]},
+            columns=self.pom_file_cols,
+            dtype="float",
+        )
+        new_df.set_index("date", inplace=True, drop=True)
+        out = new_df.combine_first(df)
+        return out
+
 
 def get_tasks(date: str = None):
     try:
@@ -178,28 +207,28 @@ def get_max_id_in_csv(tasks: List):
 
 def complete_task(task_id: str):
     row_list = []
-    with open(TASK_FILE_LOCATION, 'r') as readFile:
+    with open(TASK_FILE_LOCATION, "r") as readFile:
         reader = csv.reader(readFile)
         for row in reader:
             row_list.append(row)
             if row[0] == task_id:
-                if row[4] == '1':
-                    row[4] = '0'
+                if row[4] == "1":
+                    row[4] = "0"
                 else:
-                    row[4] = '1'
-    with open(TASK_FILE_LOCATION, 'w') as writeFile:
+                    row[4] = "1"
+    with open(TASK_FILE_LOCATION, "w") as writeFile:
         writer = csv.writer(writeFile)
         writer.writerows(row_list)
 
 
 def remove_task(task_id: str):
     row_list = []
-    with open(TASK_FILE_LOCATION, 'r') as readFile:
+    with open(TASK_FILE_LOCATION, "r") as readFile:
         reader = csv.reader(readFile)
         for row in reader:
             row_list.append(row)
             if row[0] == task_id:
                 row_list.remove(row)
-    with open(TASK_FILE_LOCATION, 'w') as writeFile:
+    with open(TASK_FILE_LOCATION, "w") as writeFile:
         writer = csv.writer(writeFile)
         writer.writerows(row_list)
