@@ -26,11 +26,14 @@ from sylo.definitions import (
     DATA_FILE_LOCATION,
     METRICS_BAR,
     METRICS_HEAT,
+    POMS_METRICS_BAR,
     DATA_FILE_CREATE,
     TASK_FILE_CREATE,
     HOME_DIR_CREATE,
-    ONE_WEEK_AGO,
+    FORTNIGHT_AGO,
     ONE_YEAR_AGO,
+    POMS_DATA_FILE_CREATE,
+    POMS_DATA_FILE_LOCATION,
 )
 from sylo.utils import (
     clear_screen,
@@ -141,8 +144,9 @@ class Sound:
 class Insights:
     def __init__(self):
         self.data_file = DATA_FILE_LOCATION
+        self.poms_file = POMS_DATA_FILE_LOCATION
         self.heatmap_start_date = ONE_YEAR_AGO
-        self.bar_start_date = ONE_WEEK_AGO
+        self.bar_start_date = FORTNIGHT_AGO
 
     def print_bar(self):
         global initial_boot_flag
@@ -154,6 +158,15 @@ class Insights:
         else:
             print("No data available, complete some segments and check later.")
 
+    def print_poms(self):
+        global initial_boot_flag
+        display.print_poms_bar_header()
+        if initial_boot_flag is False:
+            logger.info(f"Running ${self._poms_bar_chart()}")
+            run_subprocess(self._poms_bar_chart())
+        else:
+            print("No data available, complete some segments and check later.")
+
     def print_heat(self):
         logger.info(f"Running ${self._heat_map()}")
         display.print_heat_header()
@@ -162,8 +175,11 @@ class Insights:
     def _bar_chart(self):
         return METRICS_BAR % (self.data_file, self.bar_start_date)
 
+    def _poms_bar_chart(self):
+        return POMS_METRICS_BAR % (self.poms_file, self.bar_start_date)
+
     def _heat_map(self):
-        return METRICS_HEAT % (self.heatmap_start_date, self.data_file)
+        return METRICS_HEAT % (self.heatmap_start_date, self.poms_file)
 
 
 class Task:
@@ -176,7 +192,13 @@ class Task:
     def write_task_to_file(self):
         tasks = get_tasks()
         max_id = get_max_id_in_csv(tasks)
-        fields = [int(max_id) + 1, self.date, self.description, self.effort, self.complete]
+        fields = [
+            int(max_id) + 1,
+            self.date,
+            self.description,
+            self.effort,
+            self.complete,
+        ]
         with open(TASK_FILE_LOCATION, "a") as f:
             writer = csv.writer(f)
             writer.writerow(fields)
@@ -227,10 +249,10 @@ class Sylo:
         self.input_loop()
 
     def show_task(self, dates, with_id: bool = False):
-        for date, day in zip(dates, ['YESTERDAY', 'TODAY']):
-            print('\n')
+        for date, day in zip(dates, ["YESTERDAY", "TODAY"]):
+            print("\n")
             display.print_today_yesterday_tasks(day)
-            print(display.col('-----------------------------------------\n'))
+            print(display.col("-----------------------------------------\n"))
             self.tasks = get_tasks(date)
             if with_id is False:
                 display.print_tasks(self.tasks)
@@ -248,31 +270,32 @@ class Sylo:
             self.input_loop()
         while usr_input.lower() == "n":
             display.print_new_task()
-            task.description = input(display.col('Description >> ', 'yellow'))
+            task.description = input(display.col("Description >> ", "yellow"))
             task.effort = input(
-                display.col(f'Effort (in'
-                            f' {display.add_plurality(display.pom_name)}) >> ',
-                            'yellow')
+                display.col(
+                    f"Effort (in" f" {display.add_plurality(display.pom_name)}) >> ",
+                    "yellow",
+                )
             )
             task.write_task_to_file()
             self.edit_task_menu(dates)
-        while usr_input.lower() == 'c':
+        while usr_input.lower() == "c":
             clear_screen()
             display.print_header_small()
             self.show_task(dates, True)
             display.print_edit_task()
-            comp_input = input(display.col('Task id >> ', 'yellow'))
+            comp_input = input(display.col("Task id >> ", "yellow"))
             complete_task(comp_input)
             self.edit_task_menu(dates)
-        while usr_input.lower() == 'd':
+        while usr_input.lower() == "d":
             clear_screen()
             display.print_header_small()
             self.show_task(dates, True)
             display.print_remove_task()
-            comp_input = input(display.col('Task id >> ', 'yellow'))
+            comp_input = input(display.col("Task id >> ", "yellow"))
             remove_task(comp_input)
             self.edit_task_menu(dates)
-        while usr_input.lower() not in ('', 'n', 'c'):
+        while usr_input.lower() not in ("", "n", "c"):
             self.edit_task_menu(dates)
 
     def switch_modes(self):
@@ -290,6 +313,7 @@ class Sylo:
         metrics = Insights()
         metrics.print_bar()
         metrics.print_heat()
+        metrics.print_poms()
         display.print_insights(durations=self.durations)
         input(cursor)
         self.input_loop()
@@ -350,7 +374,12 @@ class Sylo:
         while response.lower() == "h":
             self.show_help_menu()
         while response.lower() == "t":
-            self.edit_task_menu([YESTERDAY_STR, TODAY_STR, ])
+            self.edit_task_menu(
+                [
+                    YESTERDAY_STR,
+                    TODAY_STR,
+                ]
+            )
         while response == "":
             self.timer_loop(timer)
 
@@ -363,6 +392,7 @@ def virgin_boostrap():
     run_subprocess(HOME_DIR_CREATE)
     run_subprocess(DATA_FILE_CREATE)
     run_subprocess(TASK_FILE_CREATE)
+    run_subprocess(POMS_DATA_FILE_CREATE)
 
 
 def config_allocation(args, config, durations: Durations):
