@@ -17,9 +17,11 @@ def run_subprocess(script: str):
     try:
         subprocess.run(script, shell=True, check=True, timeout=30)
     except subprocess.CalledProcessError:
-        print('Insights panel not loading as there is no data to display. '
-              '\nTry working for a few mins then check back later.')
-        print('\n')
+        print(
+            "Insights panel not loading as there is no data to display. "
+            "\nTry working for a few mins then check back later."
+        )
+        print("\n")
 
 
 def clear_screen():
